==> theia-0.1.8.9-py3-none-any.whl: theia/aws/network/loadbalancer.py <==
import pulumi
from pulumi_aws import lb

from typing import Optional, List, Mapping
from pydantic.dataclasses import dataclass
from theia import ResourceOptions
from theia.utils.logger import Logger
from theia._registry import StackRegistry, GlobalTags
from theia.definitions import THEIA_VERSION


logger = Logger("loadbalancer")

#=========================================================================================

@dataclass
class TargetGroupSettings:
    target_type: Optional[int] = None
    port: Optional[str] = None
    protocol: Optional[str] = None
    vpc_id: Optional[str] = None

class TargetGroup(pulumi.ComponentResource):
    def __init__(
        self,
        resource_name: str,
        target_group_settings: Optional[TargetGroupSettings]=TargetGroupSettings(),
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> None:
        super().__init__("theia:aws:network", resource_name, None, opts)
        
        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        logger.info(f"creating {resource_name} target groups")
        
        tg_args = lb.TargetGroupArgs(
            target_type=target_group_settings.target_type,
            port=target_group_settings.port,
            protocol=target_group_settings.protocol,
            vpc_id=target_group_settings.vpc_id,
            tags=merged_tags
        )

        tg_out = lb.TargetGroup(
            resource_name=resource_name,
            args=tg_args,
            opts=opts
        )
    
        pulumi.export(
            f"lb-target-group---{resource_name}",
            {
                "id": tg_out.id,
                "arn": tg_out.arn
            },
        )

        return tg_out

    @staticmethod
    def import_(stack: str, resource_name: str) -> lb.LoadBalancer:
        stack_ref = StackRegistry.get(stack_name=stack)
        loadbalancer = stack_ref.get_output(name=f"lb-loadbalancer---{resource_name}")
        return lb.LoadBalancer.get(resource_name=resource_name, id=loadbalancer["id"])


#=========================================================================================

@dataclass
class ListenerSettings:
    port: Optional[int] = None
    protocol: Optional[str] = None
    ssl_policy: Optional[str] = None
    forword_to: Optional[str] = None
    certificate_arn: Optional[str] = None

class Listener(pulumi.ComponentResource):
    def __init__(
        self,
        resource_name: str,
        listener_settings: Optional[ListenerSettings]=ListenerSettings(),
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> None:
        super().__init__("theia:aws:network", resource_name, None, opts)
        
        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        logger.info(f"creating {resource_name} listener")
        
        listener_args = lb.ListenerArgs(
            port=listener_settings.port,
            protocol=listener_settings.protocol,
            ssl_policy=listener_settings.ssl_policy,
            certificate_arn=listener_settings.certificate_arn,
            default_actions=[lb.ListenerDefaultActionArgs(
                type="forward",
                target_group_arn=listener_settings.forword_to,
            )],
            tags=merged_tags
        )

        listener_out = lb.Listener(
            resource_name=resource_name,
            args=listener_args,
            opts=opts
        )
    
        pulumi.export(
            f"lb-listener---{resource_name}",
            {
                "id": listener_out.id,
                "arn": listener_out.arn
            },
        )

        return listener_out

    @staticmethod
    def import_(stack: str, resource_name: str) -> lb.LoadBalancer:
        stack_ref = StackRegistry.get(stack_name=stack)
        loadbalancer = stack_ref.get_output(name=f"lb-loadbalancer---{resource_name}")
        return lb.LoadBalancer.get(resource_name=resource_name, id=loadbalancer["id"])


#=========================================================================================

@dataclass
class LoadbalancerSettings:
    access_logs: Optional[dict] = None,
    customer_owned_ipv4_pool: Optional[str] = None,
    desync_mitigation_mode: Optional[str] = None,
    drop_invalid_header_fields: Optional[bool] = None,
    enable_cross_zone_load_balancing: Optional[bool] = None,
    enable_deletion_protection: Optional[bool] = None,
    enable_http2: Optional[bool] = None,
    enable_tls_version_and_cipher_suite_headers: Optional[bool] = None,
    enable_waf_fail_open: Optional[bool] = None,
    enable_xff_client_port: Optional[bool] = None,
    idle_timeout: Optional[int] = None,
    internal: Optional[bool] = None,
    ip_address_type: Optional[str] = None,
    load_balancer_type: Optional[str] = None,
    name_prefix: Optional[str] = None,
    preserve_host_header: Optional[bool] = None,
    security_groups: Optional[List[str]] = None,
    subnet_mappings: Optional[List[dict]] = None,
    subnets: Optional[List[str]] = None,
    xff_header_processing_mode: Optional[str] = None

class LoadBalancer(pulumi.ComponentResource):
    def __init__(
        self,
        resource_name: str,
        lb_settings: Optional[LoadbalancerSettings]=LoadbalancerSettings(),
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> None:
        super().__init__("theia:aws:network", resource_name, None, opts)
        
        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        logger.info(f"creating {lb_settings.load_balancer_type} Loadbalancer resource {resource_name}")
        
        lb_args=lb.LoadBalancerArgs(
            name=resource_name,
            access_logs=lb_settings.access_logs,
            customer_owned_ipv4_pool=lb_settings.customer_owned_ipv4_pool,
            desync_mitigation_mode=lb_settings.desync_mitigation_mode,
            drop_invalid_header_fields=lb_settings.drop_invalid_header_fields,
            enable_cross_zone_load_balancing=lb_settings.enable_cross_zone_load_balancing,
            enable_deletion_protection=lb_settings.enable_deletion_protection,
            enable_http2=lb_settings.enable_http2,
            enable_tls_version_and_cipher_suite_headers=lb_settings.enable_tls_version_and_cipher_suite_headers,
            enable_waf_fail_open=lb_settings.enable_waf_fail_open,
            enable_xff_client_port=lb_settings.enable_xff_client_port,
            idle_timeout=lb_settings.idle_timeout,
            internal=lb_settings.internal,
            ip_address_type=lb_settings.ip_address_type,
            load_balancer_type=lb_settings.load_balancer_type,
            name_prefix=lb_settings.name_prefix,
            preserve_host_header=lb_settings.preserve_host_header,
            security_groups=lb_settings.security_groups,
            subnet_mappings=lb_settings.subnet_mappings,
            subnets=lb_settings.subnets,
            xff_header_processing_mode=lb_settings.xff_header_processing_mode,
        )

        lb_out = lb.LoadBalancer(
            resource_name=resource_name,
            args=lb_args,
            opts=opts
        )
    
        pulumi.export(
            f"lb-loadbalancer---{resource_name}",
            {
                "id": lb_out.id,
                "arn": lb_out.arn
            },
        )

        return lb_out

    @staticmethod
    def import_(stack: str, resource_name: str) -> lb.LoadBalancer:
        stack_ref = StackRegistry.get(stack_name=stack)
        loadbalancer = stack_ref.get_output(name=f"lb-loadbalancer---{resource_name}")
        return lb.LoadBalancer.get(resource_name=resource_name, id=loadbalancer["id"])

==> theia-0.1.8.10-py3-none-any.whl: theia/aws/network/loadbalancer.py <==
import pulumi
from pulumi_aws import lb
from pulumi import Output

from typing import Optional, List, Mapping
from pydantic.dataclasses import dataclass, ConfigDict
from theia import ResourceOptions
from theia.utils.logger import Logger
from theia._registry import StackRegistry, GlobalTags
from theia.definitions import THEIA_VERSION


logger = Logger("loadbalancer")

#=========================================================================================

@dataclass
class TargetGroupSettings:
    target_type: Optional[str] = None
    port: Optional[str] = None
    protocol: Optional[str] = None
    vpc_id: Optional[str] = None

class TargetGroup():
    def __new__(
        self,
        resource_name: str,
        target_group_settings: Optional[TargetGroupSettings]=TargetGroupSettings(),
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> lb.TargetGroup:
        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        logger.info(f"creating {resource_name} target groups")
        
        tg_args = lb.TargetGroupArgs(
            name=resource_name,
            target_type=target_group_settings.target_type,
            port=target_group_settings.port,
            protocol=target_group_settings.protocol,
            vpc_id=target_group_settings.vpc_id,
            tags=merged_tags
        )

        tg_out = lb.TargetGroup(
            resource_name=resource_name,
            args=tg_args,
            opts=opts
        )
    
        pulumi.export(
            f"lb-target-group---{resource_name}",
            {
                "id": tg_out.id,
                "arn": tg_out.arn
            },
        )

        return tg_out

    @staticmethod
    def import_(stack: str, resource_name: str) -> lb.LoadBalancer:
        stack_ref = StackRegistry.get(stack_name=stack)
        loadbalancer = stack_ref.get_output(name=f"lb-loadbalancer---{resource_name}")
        return lb.LoadBalancer.get(resource_name=resource_name, id=loadbalancer["id"])


#=========================================================================================

@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class ListenerSettings:
    port: Optional[int] = None
    protocol: Optional[str] = None
    ssl_policy: Optional[str] = "ELBSecurityPolicy-2016-08"
    forward_to: Optional[str | Output[str]] = None
    certificate_arn: Optional[str | Output[str]] = None
    load_balancer_arn: Optional[str | Output[str]] = None

class Listener():
    def __new__(
        self,
        resource_name: str,
        listener_settings: Optional[ListenerSettings]=ListenerSettings(),
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> lb.Listener:
        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        logger.info(f"creating {resource_name} listener")
        
        listener_args = lb.ListenerArgs(
            load_balancer_arn=listener_settings.load_balancer_arn,
            port=listener_settings.port,
            protocol=listener_settings.protocol,
            ssl_policy=listener_settings.ssl_policy,
            certificate_arn=listener_settings.certificate_arn,
            default_actions=[lb.ListenerDefaultActionArgs(
                type="forward",
                target_group_arn=listener_settings.forward_to,
            )],
            tags=merged_tags
        )

        listener_out = lb.Listener(
            resource_name=resource_name,
            args=listener_args,
            opts=opts
        )
    
        pulumi.export(
            f"lb-listener---{resource_name}",
            {
                "id": listener_out.id,
                "arn": listener_out.arn
            },
        )

        return listener_out

    @staticmethod
    def import_(stack: str, resource_name: str) -> lb.LoadBalancer:
        stack_ref = StackRegistry.get(stack_name=stack)
        loadbalancer = stack_ref.get_output(name=f"lb-loadbalancer---{resource_name}")
        return lb.LoadBalancer.get(resource_name=resource_name, id=loadbalancer["id"])


#=========================================================================================

@dataclass
class LoadbalancerSettings:
    access_logs: Optional[dict] = None
    customer_owned_ipv4_pool: Optional[str] = None
    desync_mitigation_mode: Optional[str] = None
    drop_invalid_header_fields: Optional[bool] = None
    enable_cross_zone_load_balancing: Optional[bool] = None
    enable_deletion_protection: Optional[bool] = None
    enable_http2: Optional[bool] = None
    enable_tls_version_and_cipher_suite_headers: Optional[bool] = None
    enable_waf_fail_open: Optional[bool] = None
    enable_xff_client_port: Optional[bool] = None
    idle_timeout: Optional[int] = None
    internal: Optional[bool] = False
    ip_address_type: Optional[str] = None
    load_balancer_type: Optional[str] = None
    name_prefix: Optional[str] = None
    preserve_host_header: Optional[bool] = None
    security_groups: Optional[List[str]] = None
    subnet_mappings: Optional[List[dict]] = None
    subnets: Optional[List[str]] = None
    xff_header_processing_mode: Optional[str] = None

class LoadBalancer():
    def __new__(
        self,
        resource_name: str,
        lb_settings: Optional[LoadbalancerSettings]=LoadbalancerSettings(),
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    )  -> lb.LoadBalancer:
        name: dict[str, str] = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        logger.info(f"creating {lb_settings.load_balancer_type} Loadbalancer resource {resource_name}")
        
        lb_args=lb.LoadBalancerArgs(
            name=resource_name,
            access_logs=lb_settings.access_logs,
            customer_owned_ipv4_pool=lb_settings.customer_owned_ipv4_pool,
            desync_mitigation_mode=lb_settings.desync_mitigation_mode,
            drop_invalid_header_fields=lb_settings.drop_invalid_header_fields,
            enable_cross_zone_load_balancing=lb_settings.enable_cross_zone_load_balancing,
            enable_deletion_protection=lb_settings.enable_deletion_protection,
            enable_http2=lb_settings.enable_http2,
            enable_tls_version_and_cipher_suite_headers=lb_settings.enable_tls_version_and_cipher_suite_headers,
            enable_waf_fail_open=lb_settings.enable_waf_fail_open,
            enable_xff_client_port=lb_settings.enable_xff_client_port,
            idle_timeout=lb_settings.idle_timeout,
            internal=lb_settings.internal,
            ip_address_type=lb_settings.ip_address_type,
            load_balancer_type=lb_settings.load_balancer_type,
            name_prefix=lb_settings.name_prefix,
            preserve_host_header=lb_settings.preserve_host_header,
            security_groups=lb_settings.security_groups,
            subnet_mappings=lb_settings.subnet_mappings,
            subnets=lb_settings.subnets,
            xff_header_processing_mode=lb_settings.xff_header_processing_mode,
        )

        lb_out = lb.LoadBalancer(
            resource_name=resource_name,
            args=lb_args,
            opts=opts
        )
    
        pulumi.export(
            f"lb-loadbalancer---{resource_name}",
            {
                "id": lb_out.id,
                "arn": lb_out.arn
            },
        )

        return lb_out

    @staticmethod
    def import_(stack: str, resource_name: str) -> lb.LoadBalancer:
        stack_ref = StackRegistry.get(stack_name=stack)
        loadbalancer = stack_ref.get_output(name=f"lb-loadbalancer---{resource_name}")
        return lb.LoadBalancer.get(resource_name=resource_name, id=loadbalancer["id"])
